@@ -27,6 +27,7 @@ $message = array(
     'lang' => 'ja',
     'strLang' => '日本語',
 
+    'descAllow_multiple_failover_requests_from_node' => '単一のPgpool-IIノードが複数のフェイルオーバ投票ができるどうか',
     'descAllow_sql_comments' => '負荷分散やクエリキャッシュができるかどうかの判定の際に、SQLコメントを無視するかどうか',
     'descApp_name_redirect_preference_list' => 'アプリケーション名によって負荷分散をしたいノード番号を、"アプリケーション名:ノード番号"で指定',
     'descArping_path' => 'IP アドレス切り替え後に ARP リクエストを送信するコマンドのパス',
@@ -60,6 +61,8 @@ $message = array(
     'descFailover_command' => 'ノード切り離し時に起動するコマンド',
     'descFailback_command' => 'ノード復帰時に起動するコマンド',
     'descFailover_if_affected_tuples_mismatch' => '更新行数が一致しないときにフェイルオーバ',
+    'descFailover_require_consensus' => 'クォーラム投票によりフェイルオーバを実行するかどうか',
+    'descFailover_when_quorum_exists' => 'クォーラム機能によりフェイルオーバを実行するかどうか',
     'descFail_over_on_backend_error' => 'DBノードへのソケット通信エラー時にフェイルオーバ',
     'descFollow_master_command' => 'マスタのフェイルオーバ後に実行するコマンド',
     'descHeartbeat_destination' => 'ハートビート信号の送信先ホスト名または IP アドレス',
